import { Component, Event, Prop, h } from '@stencil/core';
import Split from 'split.js';
export class WcSplit {
  constructor() {
    this.direction = 'vertical';
    this.debug = false;
    this.minHeight = 100;
    this._items = [];
    this.slots = [];
  }
  componentWillLoad() {
    if (typeof this.items === 'string') {
      this._items = JSON.parse(this.items);
    }
    else {
      this._items = this.items;
    }
  }
  componentDidLoad() {
    if (this._items && this._items.length > 0) {
      const sizes = [];
      this._items.forEach((item) => {
        sizes.push(item.size || 100);
      });
      Split(this.slots, {
        sizes: sizes,
        direction: this.direction,
        minSize: this.minHeight || 100,
        onDragEnd: this.onDragEnd.bind(this),
      });
    }
  }
  onDragEnd(newPercent) {
    const event = {};
    this.slots.forEach((s, i) => {
      const size = s.getBoundingClientRect();
      event[s.children[0]['name']] = {
        name: s.children[0]['name'],
        h: size.height,
        w: size.width,
        p: newPercent[i]
      };
    });
    this.resized.emit(event);
    if (this.debug) {
      console.debug('[ WcSplit ] - onResized', event);
    }
  }
  render() {
    return h("div", { class: 'wrapper ' + this.direction }, (this._items || []).map((item) => h("div", { ref: (el) => this.slots.push(el) },
      h("slot", { name: item.name }))));
  }
  static get is() { return "wc-split"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["wc-split.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["wc-split.css"]
  }; }
  static get properties() { return {
    "items": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "{ name: string, size: number }[] | string",
        "resolved": "string | { name: string; size: number; }[]",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "items",
      "reflect": false
    },
    "direction": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'vertical' | 'horizontal'",
        "resolved": "\"horizontal\" | \"vertical\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "direction",
      "reflect": false,
      "defaultValue": "'vertical'"
    },
    "debug": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "debug",
      "reflect": false,
      "defaultValue": "false"
    },
    "minHeight": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "min-height",
      "reflect": false,
      "defaultValue": "100"
    }
  }; }
  static get events() { return [{
      "method": "resized",
      "name": "resized",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
}
